@@ -12,8 +12,8 @@ Some of the import statements lacking below are imported from rotational_broaden
 
 import scipy.linalg as lg
 import warnings
-from src.sb2sep.rotational_broadening_function_fitting import *
-from src.sb2sep.storage_classes import InitialFitParameters
+from sb2sep.rotational_broadening_function_fitting import *
+from sb2sep.storage_classes import InitialFitParameters
 import matplotlib.pyplot as plt
 from copy import copy
 
@@ -210,7 +210,6 @@ class BroadeningFunction:
     def smooth(self):
         """
         Smoothes a calculated broadening function by convolving with a gaussian function.
-        TODO: Set so that the smoothing sigma can be calculated from spectrum resolution (2.354 * FWHM) (why?)
         """
         if self.bf is None:
             raise TypeError('self.bf is None. self.solve() must be run prior to smoothing the broadening function.')
